%--------------------------------------------------------------------------
% Caclulate transport trough the membrane
%--------------------------------------------------------------------------
function Master()
%

%%Main program with constants and for loop for iterating on the adsorption
%%enthalpy.


    clc;
    clear all;
    close all;
    global Const;
    
    avector = [];
    hvector = [];

    for i = 1:500

        % membrane/liquid constants
       
        %Const.absH1 = -50+i*50;             
        %[J/mol      ] % water absorption into sigracet enthalpy 
        Const.absH1 = -460;            
        %[J/mol      ] % water absorption into sigracet enthalpy 
        Const.absH2 = 0;              
        %[J/mol      ] % enthalpy difference from membrane and liquid water 
        
        Const.R = 8.314;             
        %[J/(K mol) ] % universal gas constant
        Const.dm = 192E-6;          
        %[m          ] % membrane thickness
        Const.ds = 246E-6;         
        %[m          ] % Sigracet thickness
        Const.Lm = 0.229;             
        %[ W/(K m)   ] % membrane conductivity
        Const.LsAA = 0.42;           
        %[ W/(K m)   ] % Sigracet 10AA conductivity
        %Const.LsAA = 0.33;            
        %[ W/(K m)   ] % Sigracet 10BA conductivity
        Const.Lw = 0.58;              
        %[ W/(K m)   ] % Water conductivity
        Const.Dm = 8.05E-9;           
        %[ m^2/s     ] % membrane diffusion coefficient
        Const.Ds = 2.3E-8;           
        %[ m^2/s     ] % Sigracet diffusion coefficient
        %ro = 1970;                  
        %[kg/m^3     ] % membrane density, wet 
        ro = 1640;                  
        %[kg/m^3     ] % membrane density, dry
        Mm = 1.1;                   
        %[kg/mol     ] % membrane molar mass
        Const.mm = Mm/ro;           
        %[m^3/mol    ] % membrane concentration
        Const.Mw = 0.018;          
        %[kg/mol     ] % water molar mass
        Const.dfH = -285000;       
        %[J/mol      ] % water liquid enthalpy of formation
        Const.cm = 75; 
        %[J/(K mol)  ] % water liquid heat capacity 
        Const.Tq = 298;             
        %[K          ] % reference temperature

        Ta = 304.5;                    %[K] Temperature in bath a 30 oC
        Tc = 301.5;                    %[K] Temperature in bath c 30 oC
        
        %Ta = 319.5;                    %[K] Temperature in bath a 45 oC
        %Tc = 316.5;                    %[K] Temperature in bath c 45 oC
        
        %Ta = 334.5;                    %[K] Temperature in bath a 60 oC
        %Tc = 331.5;                    %[K] Temperature in bath c 60 oC

        %Ta = 349.5;                     %[K] Temperature in bath a 75 oC
        %Tc = 346.5;                     %[K] Temperature in bath c 75 oC

        P = 1e5;                        %[Pa] Pressure

        [T, muT, Je, Jm] = TransportP(Ta, Tc, P);

        x = [0, Const.ds, Const.ds+Const.dm, Const.ds+Const.dm+Const.ds];

        dT = Ta-Tc;
        a = Jm/dT;
        
        avector = [avector a];
        hvector = [hvector Const.absH1];

    %figure('Units', 'pixels', ...
    %'Position', [100 100 500 375]);
    %hold on
    %TFit = line(x,T);
    %xfit1 = line([x(2) x(2)], [T(4) T(1)]); 
    %xfit2 = line([x(3) x(3)], [T(4) T(1)]); 
    %hXLabel = xlabel('d / m'                     );
    %hYLabel = ylabel('T / K'                );
    %set(TFit                          , ...
    %'LineWidth'       , 4          );
    %set(xfit1                        , ...
    %'Color'           , 'k'           , ...
    %'LineStyle'       , '--'        , ...
    %'LineWidth'      , 4            );
    %set(xfit2                        , ...
    %'Color'           , 'k'           , ...
    %'LineStyle'       , '--'        , ...
    %'LineWidth'      , 4            );


    %xlim([0 x(4)])
    %ylim([T(4) T(1)])
    
    %hLegend = legend( ...
    %[TFit, xfit1], ...
    %'Simulated flux coefficient values from MatLab' , ...
    %'Experimental flux coefficient value'                , ...
    %'location', 'NorthWest' );


    %set( gca                       , ...
    %'FontName'   , 'Helvetica', ...
    %'FontSize',45)
    % set([hXLabel, hYLabel], ...
    %'FontName'   , 'AvantGarde');
    %set(hLegend            , ...
    %'FontSize'   , 30           );
    %set([hXLabel, hYLabel]  , ...
    %'FontSize'   , 55          );

    %set(gca, ...
    %'Box'         , 'off'     , ...
    %'TickDir'     , 'out'     , ...
    %'TickLength'  , [.04 .04] , ...
    %'XMinorTick'  , 'on'      , ...
    %'YMinorTick'  , 'on'      , ...
    %'YGrid'       , 'on'      , ...
    %'XColor'      , [.3 .3 .3], ...
    %'YColor'      , [.3 .3 .3], ...
    %'LineWidth'   , 1         );
    
    %Experimental water flux, divided with the molar mass of water to
    %get the unit mol/m^2 s
    
    a = -5.032e-6/Const.Mw;
    b = -1.084e-5/Const.Mw;
    c = -1.94e-5/Const.Mw;
    d = -2.692e-5/Const.Mw;
    e = 1.034e-5/Const.Mw;
    f = 1.52e-5/Const.Mw;
    g = 3.387e-5/Const.Mw;
    h = 5.502e-5/Const.Mw;
    
    x = [];
    
    for j = 1:1:10000
        ny = -1+j*1;
        x = [x ny];
        y(j) = h;
    end
    
    end

    %%Plotting of the simulated mass flux from different adsorption 
    %%enthalpy values with experimental mass flux.
        
    figure('Units', 'pixels', ...
    'Position', [100 100 500 375]);
    hold on;
    hFit   = line(hvector,avector);
    expFit = line(x,y);
    hXLabel = xlabel('\it{\DeltaH_{abs}} \rm{/ J/mol}'                     );
    hYLabel = ylabel('\it{J_{w}/\DeltaT} \rm{/ mol/m^{2}s K}'                );
    set(hFit                          , ...
    'LineWidth'       , 4           );
    set(expFit                        , ...
    'Color'           , 'r'           , ...
    'LineStyle'       , '--'        , ...
    'LineWidth'      , 4            );

   hLegend = legend( ...
    [hFit, expFit], ...
    'Simulated values from MatLab' , ...
    'Experimental value'                , ...
    'location', 'NorthWest' );

    xlim([6800 8200])
    ylim([0.0024 0.0036])

     set( gca                       , ...
    'FontName'   , 'Helvetica', ...
    'FontSize',45)
     set([hXLabel, hYLabel], ...
    'FontName'   , 'AvantGarde');
    set(hLegend             , ...
    'FontSize'   , 30           );
    set([hXLabel, hYLabel]  , ...
    'FontSize'   , 45          );

    set(gca, ...
    'Box'         , 'off'     , ...
    'TickDir'     , 'out'     , ...
    'TickLength'  , [.04 .04] , ...
    'XMinorTick'  , 'on'      , ...
    'YMinorTick'  , 'on'      , ...
    'YGrid'       , 'on'      , ...
    'XColor'      , [.3 .3 .3], ...
    'YColor'      , [.3 .3 .3], ...
    'LineWidth'   , 1         );


end




% a_{a}=a_{c}
%This is the main program for calculation the mass and heat flux through
%the membrane cell system. 
function [T, muT, Je, Jm] = TransportP(Ta, Tc, Pa)
%
    
    global Const;
 
    Tm = (Ta + Tc) / 2;
    %The pressure is really not needed as this is a system with liquid
    %water and the resistivities are dependable on the pressure.
    Pc = Pa;                                         
    am = 1;

    Rqq = rqq_s(Ta) + rqq_m(Tm) + rqq_s(Tc);
    Rmq = rmq_s1(Ta) + rmq_m(Tm) + rmq_s2(Tc);
    Rmm = rmm_s1(Ta) + rmm_m(Tm,am) + rmm_s2(Tc);
    R = Rmm*Rqq - Rmq*Rmq;
    

    dT = 1/Tc-1/Ta;
    Jm = -dT *(Hg(Tm)*Rqq + Rmq)/R;
    Je = +dT *(Hg(Tm)*Rmq + Rmm)/R;
    dT_sa = Je*rqq_s(Ta) + Jm*rmq_s1(Ta);
    dT_mm = Je*rqq_m(Tm) + Jm*rmq_m(Tm);
    dT_sc = Je*rqq_s(Tc) + Jm*rmq_s2(Tc);
    dmuT_sa = - Je*rmq_s1(Ta) - Jm*rmm_s1(Ta);
    dmuT_mm = - Je*rmq_m(Tm) - Jm*rmm_m(Tm,am);
    dmuT_sc = - Je*rmq_s2(Tc) - Jm*rmm_s2(Tc);

    
    T = [Ta, 1/(1/Ta + dT_sa), 1/(1/Ta + dT_sa + dT_mm),...
        1/(1/Ta + dT_sa + dT_mm + dT_sc)];
    muT = [0, dmuT_sa, dmuT_sa + dmuT_mm, dmuT_sa + dmuT_mm + dmuT_sc];
    
    
%
end

%--------------------------------------------------------------------------
% Resistivities, calculation for r_{qq}, r_{mq} and r_{mm} for Sigracet
% layers and membrane.
%--------------------------------------------------------------------------


function r = rqq_m(T)
    global Const;
    r = Const.dm/Const.Lm./T./T;
end

function r = rqq_s(T)
    global Const;
    r = Const.ds/Const.LsAA./T./T;
end


function r = rmq_m(T)
    global Const;
    k = (1/Const.Lm)/((1/Const.Lm)+(1/Const.LsAA));
    h = k*(Const.absH1-Const.absH2) + Hg(T)+Const.absH2;
    r = - h*Const.dm/Const.Lm./T./T;
end

function r = rmq_s1(T)
    global Const;
    k = (1/Const.LsAA)/((1/Const.Lw)+(1/Const.LsAA));
    h = -k*Const.absH1 + Hg(T)+Const.absH1;
    r = - h*Const.ds/Const.LsAA./T./T;
end

function r = rmq_s2(T)
    global Const;
    k = (1/Const.LsAA)/((1/Const.Lm)+(1/Const.LsAA));
    h = -k*(Const.absH1-Const.absH2) + Hg(T)+Const.absH1;
    r = - h*Const.ds/Const.LsAA./T./T;
end

function r = rmm_m(T,a)
    global Const;
    k = (1/Const.Lm)/((1/Const.Lm)+(1/Const.LsAA));
    h = k*(Const.absH1-Const.absH2) + Hg(T)+Const.absH2;
    mu = Const.R*T*Const.mm./a./Xia(a);
    r = h.^2*Const.dm/Const.Lm./T./T + mu*Const.dm/Const.Dm./T;
end

function r = rmm_s1(T)
    global Const;
    k = (1/Const.LsAA)/((1/Const.Lw)+(1/Const.LsAA));
    h = -k*Const.absH1 + Hg(T)+Const.absH1;
    mu = Const.R*T/22240;
    r = h.^2*Const.ds/Const.LsAA./T./T + mu*Const.ds/Const.Ds./T;
end

function r = rmm_s2(T)
    global Const;
    k = (1/Const.LsAA)/((1/Const.Lm)+(1/Const.LsAA));
    h = -k*(Const.absH1-Const.absH2) + Hg(T)+Const.absH1;
    mu = Const.R*T/22240;
    r = h.^2*Const.ds/Const.LsAA./T./T + mu*Const.ds/Const.Ds./T;
end



%--------------------------------------------------------------------------
% Table functions
%--------------------------------------------------------------------------

% enthalpy of gas
function r = Hg(T)
%
    global Const;
    r = Const.dfH + Const.cm*(T-Const.Tq);
    %r = Const.dfH;
%
end

% membrane water content
function xi = Xi(a)
%
    if (length(a) == 1)
    %
        if      (a<0)
            xi = 0.0043;
        elseif  (a<1)
            xi = 0.043 + 17.81*a - 39.85*a.^2 + 36.0*a.^3;
        elseif  (a<3)
            %xi = 14 + 1.4*(a-1);
            xi = 16.8 - 2.8*exp(-(a-1)/0.0607);
        else
            xi = 16.8;
        end
        %xi = 14 + 1.4*(a-1);
        %xi = 0.0043 + 17.81*a - 39.85*a.^2 + 36.0*a.^3;
    %
    else
    %
        %cannot use xi = Xi(a) since there is checking of the 
        %value of each a inside xi
        xi = ones(size(a));
        for i=1:length(a)
            xi(i) = Xi(a(i)); 
        end
    %
    end
%
end

% membrane water content derivative
function xi = Xia(a)
%
    if (length(a) == 1)
    %
        if      (a<0)
            xi = 0;
        elseif  (a<1)
            xi = 17.81 - 2*39.85*a + 3*36.0*a.^2;
        elseif  (a<3)
            %xi = 1.4;
            xi = 2.8/0.0607*exp(-(a-1)/0.0607);
        else
            xi = 0;
        end
        %xi = 1.4;
        %xi = 17.81 - 2*39.85*a + 3*36.0*a.^2;
    %
    else
    %
        %cannot use xi = Xi(a) since there is checking of the 
        %value of each a inside xi
        xi = ones(size(a));
        for i=1:length(a)
            xi(i) = Xia(a(i)); 
        end
    %
    end
%
end


