%%%%%%%%%%%%%%ANODE%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    function [dy, Sigma] = anode(x,y)
        
        global Const
        
        T = y(1);
        phi = y(2);
        xw = y(3);
        Jq = y(4);
        sigma = y(5);
    
        %The parameters used in the calculations for the anode backing        
        xH2 = 1-xw;            
        Jda = ((Const.Jwa/xw)-(Const.JH2/xH2))*xw;        
        Sh2 = Const.Sh2 + Const.cph2*log(T/Const.Tq);
        Se = -2;
        Swg = Const.Swgas + Const.cpwgas*log(T/Const.Tq);
        pelta = T*(-0.5*Sh2-Se);
        qa = -T*Swg;
        
        %The differential equations in the anode backing       
        dTdx = -(1/Const.LsAA)*(Jq - qa*(Jda - Const.tad*...
             (Const.j/Const.F))-pelta*(Const.j/Const.F));
        dxwdx = -((qa*xw)/(Const.R*T*T))*dTdx - (1/Const.Dwh)*...
            (Jda-Const.tad*(Const.j/Const.F));
        dphidx = -(pelta/(T*Const.F))*dTdx-((Const.tad*Const.R*T)/...
            (Const.F*xw))*dxwdx-Const.rac*Const.j;
        dJqdx = -Const.j*dphidx-Const.JH2*Const.cph2*dTdx-Const.Jwa*...
            Const.cpwgas*dTdx;
    
        dsigmadx = -(Jq/(T*T))*dTdx-Const.R*Jda*(1/xw)*dxwdx-Const.j*...
            (1/T)*dphidx;
                
        dy = [dTdx 
            dphidx 
            dxwdx 
            dJqdx
            dsigmadx];        
        
        if nargout > 1
            Sigma = -(Jq/(T*T))*dTdx-Const.R*Jda*(1/xw)*dxwdx-Const.j*...
                (1/T)*dphidx;
        end
               
    end