%%%%%%%%%%%%ANODE SURFACE CALCULATION%%%%%%%%%%%%%%%
    
    function [Ys, Sigma] = anodesurf(Ystart) 
    
        global Const

        Tas = Ystart(1);
        phias = Ystart(2);
        xwas = Ystart(3);
        Jqas = Ystart(4);

        %Parameters used in the calculation of the anode surface        
        Hh2 = Const.cph2*(Tas-Const.Tq);    
        Hw = Const.Hwgas+Const.cpwgas*(Tas-Const.Tq);
        Sh2 = Const.Sh2 + Const.cph2*log(Tas/Const.Tq);    
        pelta = Tas*(-0.5*Sh2-Const.Se);
        qa = - Tas*(Const.Swgas+Const.cpwgas*log(Tas/Const.Tq));    
        Hwm = Const.Hwm+Const.cpw*(Tas-Const.Tq);
        qm = - Tas*(Const.Swm+Const.cpw*log(Tas/Const.Tq));  
        Swm = Const.Swm + Const.cpw*log(Tas/Const.Tq);
        Shm = Const.Sh + Const.cpH*log(Tas/Const.Tq);
       
        DeltaG = -(Hh2-Tas*Sh2);

        
        %Temperature drops
        DeltaasT = (-Jqas+qa*(Const.Jwa-Const.twm*Const.j/Const.F)+...
            pelta*Const.j/Const.F)/Const.Ls;
        DeltasmT = 0;        %Assumption

        %Electrical potential drop
        Deltaphieff = -(pelta/(Tas*Const.F))*DeltaasT-Const.rs*Const.j;       
        Deltaphi = Deltaphieff + (1/(2*Const.F))*(Hh2-Tas*Sh2);
        
        Hwvap = Const.Hwvap + (Const.cpwgas - Const.cpw)*(Tas-Const.Tq);
        
        %Energy balance
        Jqm = Jqas - Const.j*Deltaphi + Const.Jwm*Hwvap+Const.JH2*Hh2;
        
        %Output values at the anode surface
        Ts = Tas + DeltaasT;
        Tsm = Ts + DeltasmT;
        phim = phias + Deltaphi;
        
        Sigma = Jqas*((1/Ts)-(1/Tas))-(Const.j/Ts)*Deltaphieff;

        Ys = [Tsm phim Jqm];
        
    end
