%%%%%%%%%%MEMBRANE CALCULATION%%%%%%%%%%%%%%%
    
    function [dy,Sigma] = membrane(x,y)
    
        global Const
        
        T = y(1);
        phi = y(2);
        a = y(3);
        Jqm = y(4);
        sigmam = y(5);
    
        %Parameters that are used in the membrane calculation        
        Swm = Const.Swm + Const.cpw*log(T/Const.Tq);
        Sh = Const.Sh+Const.cpH*log(T/Const.Tq);
        peltm = T*(Sh - Const.twm*Swm);
        qm = -T*Swm;
        rm = 1/(exp(1268*((1/303)-(1/T))*(0.5139*Xi(a)-0.326))); 
        Lm = 0.177+3.7e-3*Xi(a);
        
        %Differential equations in the membrane        
        dTdx = -(Jqm/Lm)+(qm/Lm)*(Const.Jwm-Const.twm*...
            (Const.j/Const.F))+peltm*Const.j/(Lm*Const.F);
        dadx = -(Const.Jwm-Const.j*(Const.twm/Const.F))*Const.Mm/...
            (Xia(a)*Const.rodry*Const.Dm);
        dphidx = -(peltm/(T*Const.F))*dTdx-((Const.twm*Const.R*T)/...
            (Const.F*a))*dadx-rm*Const.j;
        dJqdx = -Const.j*dphidx-Const.Jwm*Const.cpw*dTdx;
        
        dsigmadx = -(Jqm/(T*T))*dTdx-Const.R*Const.Jwm*(1/a)*...
            dadx-Const.j*(1/T)*dphidx;
        
        dy = [dTdx
            dphidx
            dadx
            dJqdx
            dsigmadx];
        
        if nargout > 1
            Sigma = -(Jqm/(T*T))*dTdx-Const.R*Const.Jwm*(1/a)*...
                dadx-Const.j*(1/T)*dphidx;
        end
             
    end